@@ -119,7 +119,7 @@ docs/p1/sub/mymixcasetext2.txt
 		"RelPermalink: /docs/p1/sub/mymixcasetext2.txt|Name: sub/mymixcasetext2.txt|",
 		"RelPermalink: /mydata.yaml|Name: sub/data1.yaml|Title: Sub data|Params: map[]|",
 		"Featured Image: /a/pixel.png|featured.png|",
-		"Resized Featured Image: /a/pixel_hu8aa3346827e49d756ff4e630147c42b5_70_10x10_resize_box_3.png|10|",
+		"Resized Featured Image: /a/pixel_hu16809842526914527184.png|10|",
 		// Resource from string
 		"RelPermalink: /docs/p1/mytext.txt|Name: textresource|Title: My Text Resource|Params: map[param1:param1v]|",
 		// Dates
@@ -562,7 +562,7 @@ title: "p1"
 
 	b = hugolib.Test(t, files, hugolib.TestOptWarn())
 
-	b.AssertLogNotContains("WARN")
+	b.AssertLogContains("! WARN")
 }
 
 func TestPagesFromGoTmplPathWarningsPathResource(t *testing.T) {
@@ -597,7 +597,7 @@ value: data1
 
 	b = hugolib.Test(t, files, hugolib.TestOptWarn())
 
-	b.AssertLogNotContains("WARN")
+	b.AssertLogContains("! WARN")
 }
 
 func TestPagesFromGoTmplShortcodeNoPreceddingCharacterIssue12544(t *testing.T) {
@@ -678,3 +678,33 @@ summary: {{ .Summary }}|content: {{ .Content}}
 		"<p>aaa</p>|content: <p>aaa</p>\n<p>bbb</p>",
 	)
 }
+
+// Issue 13063.
+func TestPagesFromGoTmplTermIsEmpty(t *testing.T) {
+	t.Parallel()
+
+	files := `
+-- hugo.toml --
+baseURL = "https://example.com"
+disableKinds = ['section', 'home', 'rss','sitemap']
+printPathWarnings = true
+[taxonomies]
+tag = "tags"
+-- content/mypost.md --
+---
+title: "My Post"
+tags: ["mytag"]
+---
+-- content/tags/_content.gotmpl --
+{{ .AddPage (dict "path" "mothertag" "title" "My title" "kind" "term") }}
+--
+-- layouts/_default/taxonomy.html --
+Terms: {{ range .Data.Terms.ByCount }}{{ .Name }}: {{ .Count }}|{{ end }}§s
+-- layouts/_default/single.html --
+Single.
+`
+
+	b := hugolib.Test(t, files, hugolib.TestOptWarn())
+
+	b.AssertFileContent("public/tags/index.html", "Terms: mytag: 1|§s")
+}
